from .base_model import *


class HltBlankTemplate(BaseModel):
    id = models.AutoField(db_column='BlankTemplateID', primary_key=True)
    caption = models.CharField(db_column='Caption', max_length=250)
    code = models.CharField(db_column='Code', max_length=50)
    flags = models.IntegerField(db_column='Flags')
    guid = models.CharField(db_column='GUID', max_length=36)
    blank_template = models.ForeignKey('HltBlankTemplate', db_column='rf_BlankTemplateID', **FK_DEFAULT)
    template_edit = models.TextField(db_column='TemplateEdit')
    template_print = models.TextField(db_column='TemplatePrint')
    value = models.TextField(db_column='Value')
    validations = models.TextField(db_column='Validations')
    actual = models.BooleanField(db_column='Actual')
    comment = models.CharField(db_column='Comment', max_length=2000)
    source = models.CharField(db_column='Source', max_length=2000)
    author = models.CharField(db_column='Author', max_length=255)
    createdate = models.DateTimeField(db_column='CreateDate')
    rf_blank_template_type_id = models.IntegerField(db_column='rf_BlankTemplateTypeID')
    rf_context_id = models.IntegerField(db_column='rf_ContextID')
    version = models.CharField(db_column='Version', max_length=50)
    xml_data = models.TextField(db_column='XmlData')
    rf_med_record_type_guid = models.CharField(db_column='rf_MedRecordTypeGuid', max_length=36)

    class Meta:
        managed = False
        db_table = 'hlt_BlankTemplate'



from .base_model import *


class OmsOkato(BaseModel):
    """
    Коды территорий по ОКАТО
    """
    id = models.AutoField(db_column='OKATOID', primary_key=True)  
    c_okato = models.CharField(db_column='C_OKATO', max_length=15)  
    msg_text = models.CharField(db_column='MSG_TEXT', max_length=250)  
    o_name = models.CharField(db_column='O_NAME', max_length=250)  
    c_pfr = models.DecimalField(db_column='C_PFR', max_digits=5, decimal_places=0)  
    fok_name = models.CharField(db_column='FOK_NAME', max_length=60)  
    pfr_code = models.IntegerField(db_column='PFRcode')
    date_b = models.DateTimeField(db_column='Date_B')  
    date_e = models.DateTimeField(db_column='Date_E')  

    class Meta:
        managed = False
        db_table = 'oms_OKATO'



from .base_model import *


class OmsSmo(BaseModel):
    """
    Страховые медицинские организации (СМО)
    """
    id = models.AutoField(db_column='SMOID', primary_key=True)  
    okato = models.ForeignKey('OmsOkato', models.DO_NOTHING, db_column='rf_OKATOID')  
    q_ogrn = models.CharField(db_column='Q_OGRN', max_length=15)  
    q_name = models.CharField(db_column='Q_NAME', max_length=150)  
    fam_ruk = models.CharField(db_column='FAM_RUK', max_length=40)  
    im_ruk = models.CharField(db_column='IM_RUK', max_length=40)  
    ot_ruk = models.CharField(db_column='OT_RUK', max_length=40)  
    fam_bux = models.CharField(db_column='FAM_BUX', max_length=40)  
    im_bux = models.CharField(db_column='IM_BUX', max_length=40)  
    ot_bux = models.CharField(db_column='OT_BUX', max_length=40)  
    tel = models.CharField(db_column='TEL', max_length=40)  
    fax = models.CharField(db_column='FAX', max_length=40)  
    e_mail = models.CharField(db_column='E_MAIL', max_length=50)  
    date_b = models.DateTimeField(db_column='DATE_B')  
    date_e = models.DateTimeField(db_column='DATE_E')  
    address = models.CharField(db_column='ADRES', max_length=200)  
    post_idp = models.DecimalField(db_column='POST_IDP', max_digits=6, decimal_places=0)  
    okpo = models.CharField(db_column='OKPO', max_length=8)  
    cod = models.CharField(db_column='COD', max_length=6)  
    organisation = models.ForeignKey('OmsOrganisation', models.DO_NOTHING, db_column='rf_OrganisationID')  
    other_ter_flag = models.BooleanField(db_column='OtherTerFlag')
    code_cmo = models.IntegerField(db_column='Code_CMO')
    smo_cod = models.CharField(max_length=7, db_column='smocod')
    profit_type = models.ForeignKey('OmsKlProfitType', models.DO_NOTHING, db_column='rf_kl_ProfitTypeID')
    address_fact = models.CharField(db_column='ADRESF', max_length=200)
    inn = models.CharField(db_column='INN', max_length=17)
    kpp = models.DecimalField(db_column='KPP', max_digits=9, decimal_places=0)
    post_idpf = models.DecimalField(db_column='POST_IDPF', max_digits=6, decimal_places=0)
    q_namef = models.CharField(db_column='Q_NAMEF', max_length=255)
    rem = models.CharField(db_column='Rem', max_length=255)

    flags = models.IntegerField(db_column='FLAGS')

    class Meta:
        managed = False
        db_table = 'oms_SMO'



from .base_model import *


class OmsDepartment(BaseModel):
    id = models.AutoField(db_column='DepartmentID', primary_key=True)
    uuid = models.CharField(db_column='GUIDDepartment', max_length=36, unique=True)

    code = models.CharField(db_column='DepartmentCODE', max_length=50)
    name = models.CharField(db_column='DepartmentNAME', max_length=255)
    type = models.ForeignKey('OmsKlDepartmentType', db_column='rf_kl_DepartmentTypeID', **FK_DEFAULT)
    lpu = models.ForeignKey('OmsLpu', models.DO_NOTHING, db_column='rf_LPUID')
    zav_pcod = models.CharField(db_column='ZAVPCOD', max_length=10)
    zav_fio = models.CharField(db_column='ZAVFIO', max_length=70)
    profile = models.ForeignKey('OmsKlDepartmentProfile', db_column='rf_kl_DepartmentProfileID', **FK_DEFAULT)
    code_department = models.IntegerField(db_column='Code_Department')
    n_otd = models.CharField(db_column='N_OTD', max_length=5)
    rem = models.CharField(db_column='Rem', max_length=255)
    age_group = models.ForeignKey('OmsKlAgeGroup', db_column='rf_kl_AgeGroupID', **FK_DEFAULT)
    date_b = models.DateTimeField(db_column='Date_B')
    date_e = models.DateTimeField(db_column='Date_E')
    code_kladr = models.CharField(db_column='CodeKLADR', max_length=10)
    fax = models.CharField(db_column='FAX', max_length=50)
    address = models.ForeignKey('KlaAddress', db_column='rf_AddressID', **FK_DEFAULT)
    tel = models.CharField(db_column='Tel', max_length=50)
    med_care_type = models.ForeignKey('OmsKlMedCareType', db_column='rf_kl_MedCareTypeID', **FK_DEFAULT)

    class Meta:
        managed = False
        db_table = 'oms_Department'



from .base_model import *


class OmsOkved(BaseModel):
    """
    Код экономического вида деятельности по ОКВЭД
    """
    id = models.AutoField(db_column='OKVEDID', primary_key=True)
    uuid = models.CharField(db_column='UGUID', max_length=36, unique=True, default=uuid.uuid4)
    name = models.CharField(db_column='NAME', max_length=100)
    code = models.CharField(db_column='OKVED_CODE', max_length=10)
    date_in = models.DateTimeField(db_column='DATEIN')
    date_out = models.DateTimeField(db_column='DATEOUT')
    date_edit = models.DateTimeField(db_column='DATEEDIT')

    class Meta:
        managed = False
        db_table = 'oms_OKVED'



from .base_model import *


class OmsOrganisation(BaseModel):
    """
    Организации
    """
    id = models.AutoField(db_column='OrganisationID', primary_key=True)
    uuid = models.CharField(db_column='GUIDOrg', max_length=36, default=uuid.uuid4)
    fullname = models.CharField(db_column='FullName', max_length=200)
    shortname = models.CharField(db_column='ShortName', max_length=80)
    inn = models.CharField(db_column='INN', max_length=17)
    kpp = models.CharField(db_column='KPP', max_length=14)
    r_account = models.CharField(db_column='R_Account', max_length=25)
    bank = models.CharField(db_column='Bank', max_length=150)
    bik_bank = models.CharField(db_column='BIK_Bank', max_length=14)
    c_account = models.CharField(db_column='C_Account', max_length=25)
    ogrn = models.CharField(db_column='OGRN', max_length=15)
    c_okpo = models.CharField(db_column='C_OKPO', max_length=15)
    okato = models.ForeignKey('OmsOkato', models.DO_NOTHING, db_column='rf_OKATOID')
    okved = models.ForeignKey('OmsOkved', models.DO_NOTHING, db_column='rf_OKVEDID')
    address = models.CharField(db_column='Address', max_length=200)
    phone = models.CharField(db_column='Phone', max_length=40)
    fax = models.CharField(db_column='Fax', max_length=40)
    email = models.CharField(db_column='Email', max_length=40)
    fio_ruk = models.CharField(db_column='FIO_RUK', max_length=100)
    fio_bux = models.CharField(db_column='FIO_BUX', max_length=100)
    date_b = models.DateTimeField(db_column='Date_B')
    date_e = models.DateTimeField(db_column='Date_E')
    parent = models.ForeignKey('self', models.DO_NOTHING, db_column='rf_OrganisationParentID')
    code = models.CharField(db_column='Code', max_length=15)
    address_p = models.CharField(db_column='AdresP', max_length=250)
    docum = models.CharField(db_column='Docum', max_length=150)
    dop = models.CharField(db_column='Dop', max_length=250)
    fio_ruk_r = models.CharField(db_column='FIO_RUK_R', max_length=100)
    post = models.CharField(db_column='Post', max_length=150)
    rem = models.CharField(db_column='Rem', max_length=250)
    kla_address = models.ForeignKey('KlaAddress', models.DO_NOTHING, db_column='rf_AddressID')

    flags = models.IntegerField(db_column='FLAGS')

    class Meta:
        managed = False
        db_table = 'oms_Organisation'



from .base_model import *


class HltUchastok(BaseModel):
    id = models.AutoField(db_column='UchastokID', primary_key=True)
    uuid = models.CharField(db_column='UGUID', max_length=36, unique=True)

    caption = models.CharField(db_column='UchastoCaption', max_length=500)
    code = models.CharField(db_column='CODE', max_length=6)
    doctor = models.ForeignKey('HltLpuDoctor', db_column='rf_LPUDoctorID', **FK_DEFAULT)
    doc_prvd = models.ForeignKey('HltDocPrvd', db_column='rf_DocPRVDID', **FK_DEFAULT)
    type_uid = models.IntegerField(db_column='rf_kl_TypeUID')
    lpu = models.ForeignKey('OmsLpu', db_column='rf_LPUID', **FK_DEFAULT)
    is_closed = models.IntegerField(db_column='isClosed')
    code_smo = models.CharField(db_column='CodeSMO', max_length=6)
    date_begin = models.DateTimeField(db_column='DateBegin')
    date_end = models.DateTimeField(db_column='DateEnd')
    flags = models.IntegerField(db_column='Flags')

    class Meta:
        managed = False
        db_table = 'hlt_Uchastok'



from .base_model import *


class OmsPrvs(models.Model):
    id = models.AutoField(db_column='PRVSID', primary_key=True)
    c_prvs = models.CharField(db_column='C_PRVS', max_length=100)
    prvs_name = models.CharField(db_column='PRVS_NAME', max_length=100)
    msg_text = models.CharField(db_column='MSG_TEXT', max_length=100)
    i_prvs = models.IntegerField(db_column='I_PRVS')
    date_beg = models.DateTimeField(db_column='Date_Beg')
    date_end = models.DateTimeField(db_column='Date_End')
    main_prvs = models.ForeignKey('self', db_column='rf_MainPRVSID', **FK_DEFAULT)
    prvs = models.ForeignKey('self', db_column='rf_PRVSID', **FK_DEFAULT)
    id_post_mz = models.CharField(db_column='IDPost_MZ', max_length=50)
    post_name = models.CharField(db_column='PostName', max_length=150)
    profit_type = models.ForeignKey('OmsKlProfitType', db_column='rf_kl_ProfitTypeID', **FK_DEFAULT)
    prvd = models.ForeignKey('OmsPrvd', db_column='rf_PRVDID', **FK_DEFAULT)

    class Meta:
        managed = False
        db_table = 'oms_PRVS'



from .base_model import *


class OmsPrvd(BaseModel):
    """
    В: Должности
    """
    id = models.AutoField(db_column='PRVDID', primary_key=True) 
    name = models.CharField(db_column='NAME', max_length=100) 
    c_prvd = models.CharField(db_column='C_PRVD', max_length=50) 
    msg_text = models.CharField(db_column='MSG_TEXT', max_length=100) 
    date_b = models.DateTimeField(db_column='Date_B') 
    date_e = models.DateTimeField(db_column='Date_E') 
    profit_type = models.ForeignKey('OmsKlProfitType', models.DO_NOTHING, db_column='rf_kl_ProfitTypeID')

    class Meta:
        managed = False
        db_table = 'oms_PRVD'



from .base_model import *


class KlaKladr(BaseModel):
    id = models.AutoField(db_column='KlAdrID', primary_key=True)  
    name = models.CharField(db_column='Name', max_length=40)  
    socr = models.CharField(db_column='SOCR', max_length=10)  
    code = models.CharField(db_column='CODE', max_length=13)  
    gninmb = models.CharField(db_column='GNINMB', max_length=4)  
    uno = models.CharField(db_column='UNO', max_length=4)  
    ocatd = models.CharField(db_column='OCATD', max_length=11)  
    status = models.CharField(db_column='STATUS', max_length=1)  
    source = models.CharField(db_column='Source', max_length=5)  
    level = models.IntegerField(db_column='LEVEL')  
    alt_code = models.CharField(db_column='AltCode', max_length=50)  
    post_index = models.CharField(db_column='PostIndex', max_length=6)  
    parent = models.ForeignKey('self', models.DO_NOTHING, db_column='rf_ParentID')  
    address_string = models.CharField(db_column='AddressString', max_length=500)  
    
    flags = models.IntegerField(db_column='FLAGS')  

    class Meta:
        managed = False
        db_table = 'kla_Kladr'



from collections import namedtuple
from enum import Enum
from typing import Tuple, Any

from django.db import connections


class ResultType(Enum):
    TUPLE = 0
    DICT = 1
    NAMEDTUPLE = 2


# noinspection PyArgumentList
def select_all(sql: str, params: Tuple[Any] = None, result_type: ResultType = ResultType.TUPLE):
    with connections['tmmis'].cursor() as cursor:
        cursor.execute(sql, params)
        if result_type == ResultType.DICT:
            columns = [col[0] for col in cursor.description]
            return [
                dict(zip(columns, row))
                for row in cursor.fetchall()
            ]
        elif result_type == ResultType.NAMEDTUPLE:
            desc = cursor.description
            result = namedtuple('Result', [col[0] for col in desc])
            return [result(*row) for row in cursor.fetchall()]
        else:
            return cursor.fetchall()


def select_one(sql: str, params: Tuple[Any] = None):
    with connections['tmmis'].cursor() as cursor:
        cursor.execute(sql, params)
        return cursor.fetchone()


def query(sql: str, params: Tuple[Any] = None):
    with connections['tmmis'].cursor() as cursor:
        cursor.execute(sql, params)



from .base_model import *


class HltTap(BaseModel):
    """
    Талон амбулаторного пациента
    """
    id = models.AutoField(db_column='TAPID', primary_key=True)
    uuid = models.CharField(db_column='UGUID', max_length=36, unique=True, default=uuid.uuid4)
    mkab = models.ForeignKey('HltMkab', models.DO_NOTHING, db_column='rf_MKABID', related_name='taps')
    katl = models.IntegerField(db_column='rf_KATLID')
    mkb = models.ForeignKey('OmsMkb', db_column='rf_MKBID', **FK_DEFAULT)
    mkb2 = models.ForeignKey('OmsMkb', db_column='rf_MKB2ID', **FK_DEFAULT)
    reason_care = models.ForeignKey('HltReasonCare', db_column='rf_ReasonCareID', **FK_DEFAULT)
    care_person_sex = models.BooleanField(db_column='CarePersonSex')
    care_person_age = models.IntegerField(db_column='CarePersonAge')
    date_tap = models.DateTimeField(db_column='DateTAP')
    inv = models.IntegerField(db_column='rf_INVID')
    not_work_doc_status = models.IntegerField(db_column='rf_NotWorkDocStatusID')
    date_close = models.DateTimeField(db_column='DateClose')
    lpu_doctor = models.ForeignKey('HltLpuDoctor', db_column='rf_LPUDoctorID', **FK_DEFAULT)
    lpu_doctor_s = models.ForeignKey('HltLpuDoctor', db_column='rf_LPUDoctor_SID', **FK_DEFAULT)
    smo = models.ForeignKey('OmsSmo', db_column='rf_SMOID', **FK_DEFAULT)
    other_smo = models.ForeignKey('OmsSmo', db_column='rf_OtherSMOID', **FK_DEFAULT)
    s_pol = models.CharField(db_column='S_POL', max_length=50)
    n_pol = models.CharField(db_column='N_POL', max_length=50)
    isclosed = models.BooleanField(db_column='IsClosed')
    is_worker = models.BooleanField(db_column='isWorker')
    spec_event_cert = models.IntegerField(db_column='rf_SpecEventCertID')
    care_begin = models.DateTimeField(db_column='CareBegin')
    care_end = models.DateTimeField(db_column='CareEnd')
    family = models.CharField(db_column='FAMILY', max_length=40)
    mkab_sheet_final_ds = models.IntegerField(db_column='rf_MKABSheetFinalDSID')
    direction = models.IntegerField(db_column='rf_DirectionID')
    outcome_visit = models.IntegerField(db_column='rf_OutcomeVisitID')
    description = models.CharField(db_column='Description', max_length=1000)
    profit_type = models.IntegerField(db_column='rf_kl_ProfitTypeID')
    disp_reg_state = models.IntegerField(db_column='rf_kl_DispRegStateID')
    disp_reg_state2 = models.IntegerField(db_column='rf_kl_DispRegState2ID')
    disease_type = models.ForeignKey('OmsKlDiseaseType', db_column='rf_kl_DiseaseTypeID', **FK_DEFAULT)
    disease_type2 = models.ForeignKey('OmsKlDiseaseType', db_column='rf_kl_DiseaseType2ID', **FK_DEFAULT)
    trauma_type = models.IntegerField(db_column='rf_kl_TraumaTypeID')
    sick_list_reason = models.IntegerField(db_column='rf_kl_SickListReasonID')
    visit_result = models.IntegerField(db_column='rf_kl_VisitResultID')
    registration_end_reason = models.IntegerField(db_column='rf_kl_RegistrationEndReasonID')
    registration_end_reason2 = models.IntegerField(db_column='rf_kl_RegistrationEndReason2ID')
    health_group = models.IntegerField(db_column='rf_kl_HealthGroupID')
    visit_place = models.IntegerField(db_column='rf_kl_VisitPlaceID')
    reason_type = models.ForeignKey('OmsKlReasonType', db_column='rf_kl_ReasonTypeID', **FK_DEFAULT)
    department = models.ForeignKey('OmsDepartment', db_column='rf_DepartmentID', **FK_DEFAULT)
    soc_status = models.ForeignKey('OmsKlSocStatus', db_column='rf_kl_SocStatusID', **FK_DEFAULT)
    create_username = models.CharField(db_column='CreateUserName', max_length=255)
    edit_username = models.CharField(db_column='EditUserName', max_length=255)
    flag_bill = models.BooleanField(db_column='FlagBill')
    flag_statist = models.BooleanField(db_column='FlagStatist')
    create_user = models.ForeignKey('XUser', db_column='rf_CreateUserID', **FK_DEFAULT)
    edit_user = models.ForeignKey('XUser', db_column='rf_EditUserID', **FK_DEFAULT)
    stat_cure_result = models.IntegerField(db_column='rf_kl_StatCureResultID')
    polis_mkab = models.IntegerField(db_column='rf_PolisMKABID')
    type_tap = models.IntegerField(db_column='rf_TypeTAPID')
    registr_patient = models.IntegerField(db_column='rf_RegistrPatientID')
    doc_prvd = models.ForeignKey('HltDocPrvd', db_column='rf_DocPRVDID', **FK_DEFAULT)
    mkp_card = models.UUIDField(db_column='rf_mkp_CardGUID')
    date_create_tap = models.DateTimeField(db_column='DateCreateTAP')
    num_in_other_system = models.CharField(db_column='NumInOtherSystem', max_length=50)
    is_dvn_closed = models.BooleanField(db_column='isDVNClosed')
    med_care_type = models.IntegerField(db_column='rf_kl_MedCareTypeID')
    disability_status = models.IntegerField(db_column='DisabilityStatus')
    reason_inv = models.IntegerField(db_column='rf_kl_ReasonInvID')
    mkb_external = models.ForeignKey('OmsMkb', db_column='rf_MKBExternalID', **FK_DEFAULT)
    sanitation = models.IntegerField(db_column='rf_kl_SanitationID')
    patient_status = models.IntegerField(db_column='rf_kl_PatientStatusID')
    onco_sign = models.IntegerField(db_column='rf_onco_SignID')
    dd_service = models.IntegerField(db_column='rf_kl_DDServiceID')
    tip_oms = models.ForeignKey('OmsKlTipOms', db_column='rf_kl_TipOMSID', **FK_DEFAULT)
    num = models.IntegerField(db_column='Num')

    flags = models.IntegerField(db_column='Flags')

    class Meta:
        managed = False
        db_table = 'hlt_TAP'



from .base_model import *


class HltTypeCallDoctor(BaseModel):
    id = models.AutoField(db_column='TypeCallDoctorID', primary_key=True)
    code = models.CharField(db_column='CODE', max_length=1)
    name = models.CharField(db_column='NAME', max_length=20)
    date_begin = models.DateTimeField(db_column='DateBegin')
    date_end = models.DateTimeField(db_column='DateEnd')
    enum_name = models.CharField(db_column='EnumName', max_length=50)
    flags = models.IntegerField(db_column='Flags')

    class Meta:
        managed = False
        db_table = 'hlt_TypeCallDoctor'



from .base_model import *


class OmsMkb(BaseModel):
    """
    Классификатор болезней МКБ-10
    """
    id = models.AutoField(db_column='MKBID', primary_key=True)
    ds = models.CharField(db_column='DS', max_length=10)
    name = models.CharField(db_column='NAME', max_length=255)
    date_b = models.DateField(db_column='Date_B')
    date_e = models.DateField(db_column='Date_E')
    rem = models.CharField(db_column='Rem', max_length=250)

    flags = models.IntegerField(db_column='Flags')

    class Meta:
        managed = False
        db_table = 'oms_MKB'



from .base_model import *


class XUser(BaseModel):
    id = models.AutoField(db_column='UserID', primary_key=True)
    uuid = models.CharField(db_column='GUID', max_length=36, unique=True)
    windows_name = models.CharField(db_column='WindowsName', max_length=500)  
    general_login = models.CharField(db_column='GeneralLogin', max_length=50)  
    general_password = models.CharField(db_column='GeneralPassword', max_length=50)  
    auth_mode = models.SmallIntegerField(db_column='AuthMode')  
    fio = models.CharField(db_column='FIO', max_length=50, blank=True, null=True)  
    email = models.CharField(db_column='Email', max_length=256)

    class Meta:
        managed = False
        db_table = 'x_User'



from .base_model import *


class AtfFileInfo(BaseModel):
    """
    Информация о прикрепленном документе
    """
    id = models.AutoField(db_column='FileInfoID', primary_key=True)
    uuid = models.CharField(db_column='Guid', max_length=36, unique=True, default=uuid.uuid4)

    date_doc = models.DateTimeField('Дата документа', db_column='DateDoc', default=timezone.now)
    desc_guid = models.CharField('Уникальный идентификатор источника', db_column='DescGuid', max_length=36)
    description = models.TextField('Описание', db_column='Description', default='')
    doctor_name = models.CharField('ФИО врача', db_column='DoctorName', max_length=255, default='')
    lpu_name = models.CharField('Наименование ЛПУ', db_column='LPUName', max_length=255, default='')
    desc_type = models.CharField('Тип документа источника', db_column='rf_DescTypeGuid', max_length=36)
    doctor_guid = models.CharField('Врач', db_column='rf_DoctorGuid', max_length=36,
                                   default='00000000-0000-0000-0000-000000000000')
    doctor_type = models.CharField('Тип элемента БД, характеризующий доктора', db_column='rf_DoctorTypeGuid',
                                   max_length=36, default='00000000-0000-0000-0000-000000000000')
    file_type = models.ForeignKey('AtfFileType', db_column='rf_FileTypeID', **FK_DEFAULT)
    lpu = models.ForeignKey('OmsLpu', to_field='uuid', db_column='rf_LPUGuid', max_length=36, **FK_DEFAULT)
    lpu_type = models.CharField(db_column='rf_LPUTypeGuid', max_length=36)

    flags = models.IntegerField(db_column='Flags', default=0)

    class Meta:
        managed = False
        db_table = 'atf_FileInfo'



from .base_model import *


class OmsLpu(BaseModel):
    """
    Лечебно-профилактические учреждения (ЛПУ)
    """
    id = models.AutoField(db_column='LPUID', primary_key=True)
    uuid = models.CharField(db_column='GUIDLPU', max_length=36, unique=True, default=uuid.uuid4)
    okato = models.ForeignKey('OmsOkato', models.DO_NOTHING, db_column='rf_OKATOID')
    c_ogrn = models.CharField(db_column='C_OGRN', max_length=15)
    m_names = models.CharField(db_column='M_NAMES', max_length=200)
    m_namef = models.CharField(db_column='M_NAMEF', max_length=1000)
    c_inn = models.CharField(db_column='C_INN', max_length=15)
    c_kpp = models.CharField(db_column='C_KPP', max_length=15)
    c_okved = models.CharField(db_column='C_OKVED', max_length=50)
    c_okogu = models.CharField(db_column='C_OKOGU', max_length=10)
    fam_gv = models.CharField(db_column='FAM_GV', max_length=40)
    im_gv = models.CharField(db_column='IM_GV', max_length=40)
    ot_gv = models.CharField(db_column='OT_GV', max_length=40)
    fam_bux = models.CharField(db_column='FAM_BUX', max_length=40)
    im_bux = models.CharField(db_column='IM_BUX', max_length=40)
    ot_bux = models.CharField(db_column='OT_BUX', max_length=40)
    tel = models.CharField(db_column='TEL', max_length=40)
    fax = models.CharField(db_column='FAX', max_length=40)
    e_mail = models.CharField(db_column='E_MAIL', max_length=50)
    date_b = models.DateTimeField(db_column='DATE_B')
    date_e = models.DateTimeField(db_column='DATE_E')
    c_n_fil = models.SmallIntegerField(db_column='C_N_FIL')
    address = models.CharField(db_column='ADRES', max_length=200)
    mcod = models.CharField(db_column='MCOD', unique=True, max_length=10)
    klpu = models.CharField(db_column='KLPU', max_length=1)
    post_idp = models.DecimalField(db_column='POST_IDP', max_digits=6, decimal_places=0)
    okpo = models.CharField(db_column='OKPO', max_length=8)
    organisation = models.ForeignKey('OmsOrganisation', models.DO_NOTHING, db_column='rf_OrganisationID')
    # tariff_type = models.ForeignKey('OmsKlTariffType', models.DO_NOTHING, db_column='rf_kl_TariffTypeID')
    # category = models.ForeignKey('OmsKlCategory', models.DO_NOTHING, db_column='rf_kl_CategoryID')
    ndog = models.CharField(db_column='NDOG', max_length=50)
    ddogfss = models.DateTimeField(db_column='DDOGFSS')
    lic = models.CharField(db_column='Lic', max_length=50)
    code_mo = models.IntegerField(db_column='Code_MO')
    fcod = models.CharField(db_column='FCOD', max_length=6)
    # type_lpu = models.ForeignKey('OmsKlTypeLpu', models.DO_NOTHING, db_column='rf_kl_Type_LPUID')
    main_lpu = models.ForeignKey('self', models.DO_NOTHING, db_column='rf_MainLPUID')
    stlpu = models.CharField(db_column='StLPU', max_length=1)
    # agegroup = models.ForeignKey('OmsKlAgegroup', models.DO_NOTHING, db_column='rf_kl_AgeGroupID')
    # tariff_target = models.ForeignKey('OmsTariffTarget', models.DO_NOTHING, db_column='rf_TariffTargetID')
    in_demand = models.BooleanField(db_column='InDemand')
    date_n_beg = models.DateTimeField(db_column='DateN_Beg')
    date_n_end = models.DateTimeField(db_column='DateN_End')
    code_kladr = models.CharField(db_column='CodeKladr', max_length=10)
    code_ruk = models.CharField(db_column='CodeRuk', max_length=10)
    dop_fk = models.CharField(db_column='DopFK', max_length=10)
    host = models.IntegerField(db_column='HostID')
    kfsr = models.CharField(db_column='KFSR', max_length=10)
    kosgu = models.CharField(db_column='KOSGU', max_length=10)
    kvr = models.CharField(db_column='KVR', max_length=10)
    kvsr = models.CharField(db_column='KVSR', max_length=10)
    kla_address = models.ForeignKey('KlaAddress', models.DO_NOTHING, db_column='rf_AddressID')
    prvd = models.ForeignKey('OmsPrvd', models.DO_NOTHING, db_column='rf_PRVDID')
    mdlpc_ode = models.CharField(db_column='MdlpCode', max_length=150)
    code_egisz = models.CharField(db_column='CodeEgisz', max_length=150)
    # med_care_type = models.ForeignKey('OmsKlMedCareType', models.DO_NOTHING, db_column='rf_kl_MedCareTypeID')

    flags = models.IntegerField(db_column='FLAGS')

    class Meta:
        managed = False
        db_table = 'oms_LPU'



# noinspection PyUnresolvedReferences
import uuid

from django.db import models
# noinspection PyUnresolvedReferences
from django.utils import timezone

FK_DEFAULT = {
    'on_delete'   : models.DO_NOTHING,
    'related_name': '+'
}


class BaseModel(models.Model):
    x_edition = models.IntegerField(db_column='x_Edition', default=1)
    x_status = models.SmallIntegerField(db_column='x_Status', default=1)

    class Meta:
        abstract = True



from .base_model import *


class OmsKlDiseaseType(BaseModel):
    id = models.AutoField(db_column='kl_DiseaseTypeID', primary_key=True)
    code = models.CharField(db_column='CODE', max_length=50)
    name = models.CharField(db_column='NAME', max_length=255)
    date_b = models.DateTimeField(db_column='Date_B')
    date_e = models.DateTimeField(db_column='Date_E')

    class Meta:
        managed = False
        db_table = 'oms_kl_DiseaseType'



from .base_model import *


class OmsKlStatCureResult(BaseModel):
    id = models.AutoField(db_column='kl_StatCureResultID', primary_key=True)
    guid = models.CharField(db_column='StatCureResultGUID', max_length=36)

    code = models.CharField(db_column='CODE', max_length=50)
    name = models.CharField(db_column='NAME', max_length=255)
    date_b = models.DateTimeField(db_column='Date_B')
    date_e = models.DateTimeField(db_column='Date_E')
    department_type = models.ForeignKey('OmsKlDepartmentType', db_column='rf_kl_DepartmentTypeID', **FK_DEFAULT)
    code_region = models.CharField(db_column='CODE_Region', max_length=50)
    code_federal = models.CharField(db_column='CODE_Federal', max_length=50)

    class Meta:
        managed = False
        db_table = 'oms_kl_StatCureResult'



from .base_model import *


class HltCallDoctor(BaseModel):
    id = models.AutoField(db_column='CallDoctorID', primary_key=True)
    lpu_doctor = models.ForeignKey('HltLpuDoctor', db_column='rf_LPUDoctorID', **FK_DEFAULT)
    mkab = models.ForeignKey('HltMkab', db_column='rf_MKABID', **FK_DEFAULT)
    address = models.CharField(db_column='Address', max_length=200)
    complaint = models.CharField(db_column='Complaint', max_length=500)
    date_call = models.DateTimeField(db_column='DateCall')
    status = models.ForeignKey('HltCallDoctorStatus', db_column='rf_CallDoctorStatusID', **FK_DEFAULT)
    is_finalize = models.BooleanField(db_column='isFinalize')
    date_finalize = models.DateTimeField(db_column='DateFinalize')
    tap = models.ForeignKey('HltTap', **FK_DEFAULT, db_column='rf_TAPID')
    code_domophon = models.CharField(db_column='CodeDomophon', max_length=20)
    phone = models.CharField(db_column='Phone', max_length=25)
    finalize_lpu_doctor = models.ForeignKey('HltLpuDoctor', db_column='Rf_FinalizeLPUDoctorID', **FK_DEFAULT)
    description = models.CharField(db_column='Description', max_length=100)
    type_call_doctor = models.ForeignKey('HltTypeCallDoctor', db_column='rf_TypeCallDoctorID', **FK_DEFAULT)
    entrance = models.IntegerField(db_column='Entrance')
    floor = models.IntegerField(db_column='Floor')
    rf_address = models.ForeignKey('KlaAddress', db_column='rf_AddressID', **FK_DEFAULT)
    doc_prvd = models.ForeignKey('HltDocPrvd', db_column='rf_DocPRVDID', **FK_DEFAULT)
    finalize_doc_prvd = models.ForeignKey('HltDocPrvd', db_column='rf_FinalizeDocPRVDID', **FK_DEFAULT)
    date_visit = models.DateTimeField(db_column='DateVisit')
    guid = models.CharField(db_column='GUID', max_length=36)
    lpu = models.ForeignKey('OmsLpu', db_column='rf_LPUID', **FK_DEFAULT)
    source_dvt = models.IntegerField(db_column='SourceDvt')
    birth_date = models.DateTimeField(db_column='BirthDate')
    date_status = models.DateTimeField(db_column='DateStatus')
    family = models.CharField(db_column='Family', max_length=40)
    name = models.CharField(db_column='Name', max_length=40)
    number_pol = models.CharField(db_column='NumberPol', max_length=50)
    ot = models.CharField(db_column='Ot', max_length=40)
    rf_kl_sexid = models.IntegerField(db_column='rf_kl_SexID')
    mkb = models.ForeignKey('OmsMkb', db_column='rf_MKBID', **FK_DEFAULT)
    series_pol = models.CharField(db_column='SeriesPol', max_length=50)
    cause_cancel = models.TextField(db_column='CauseCancel')
    source_smp = models.TextField(db_column='SourceSmp')
    call_family = models.CharField(db_column='Call_Family', max_length=40)
    call_name = models.CharField(db_column='Call_Name', max_length=40)
    call_patronymic = models.CharField(db_column='Call_Patronymic', max_length=40)
    rf_call_person_type_id = models.IntegerField(db_column='rf_CallPersonTypeID')
    age = models.IntegerField(db_column='Age')
    age_title = models.IntegerField(db_column='AgeTitle')
    date_active = models.DateTimeField(db_column='DateActive')
    date_resolved = models.DateTimeField(db_column='DateResolved')
    is_child = models.BooleanField(db_column='isChild')
    is_notification = models.BooleanField(db_column='IsNotification')
    uchastok = models.ForeignKey('HltUchastok', db_column='rf_UchastokID', **FK_DEFAULT)
    age_group = models.ForeignKey('OmsKlAgeGroup', db_column='rf_kl_AgeGroupID', **FK_DEFAULT)
    rf_call_cancel_reason_id = models.IntegerField(db_column='rf_CallCancelReasonID')
    is_sent_to_doctor = models.BooleanField(db_column='IsSentToDoctor')

    flags = models.IntegerField(db_column='Flags')

    class Meta:
        managed = False
        db_table = 'hlt_CallDoctor'



from .base_model import *


class HltDoctorTimeTable(BaseModel):
    id = models.AutoField(db_column='DoctorTimeTableID', primary_key=True)
    begin_time = models.DateTimeField(db_column='Begin_Time')
    end_time = models.DateTimeField(db_column='End_Time')
    date = models.DateTimeField(db_column='Date')
    lpu_doctor = models.ForeignKey('HltLpuDoctor', db_column='rf_LPUDoctorID', **FK_DEFAULT)
    doc_busy_type_id = models.IntegerField(db_column='rf_DocBusyType')
    flag_access = models.IntegerField(db_column='FlagAccess')
    flags = models.IntegerField(db_column='FLAGS')
    uguid = models.CharField(db_column='UGUID', max_length=36)
    last_stub_num = models.IntegerField(db_column='LastStubNum')
    plan_ue = models.IntegerField(db_column='PlanUE')
    doc_prvd = models.ForeignKey('HltDocPrvd', db_column='rf_DocPRVDID', **FK_DEFAULT)
    healing_room_id = models.IntegerField(db_column='rf_HealingRoomID')
    tt_source = models.IntegerField(db_column='TTSource')
    used_ue = models.IntegerField(db_column='UsedUE')
    is_katl_visit = models.BooleanField(db_column='IsKatlVisit')
    is_out_schedule = models.BooleanField(db_column='IsOutSchedule')
    comment_mobil_brigade = models.CharField(db_column='CommentMobilBrigade', max_length=1000)
    address_mobil_brigade_id = models.IntegerField(db_column='rf_AddressMobilBrigadeID')

    class Meta:
        managed = False
        db_table = 'hlt_DoctorTimeTable'



from .base_model import *


class OmsKlMedCareType(BaseModel):
    id = models.AutoField(db_column='kl_MedCareTypeID', primary_key=True)  
    code = models.CharField(db_column='CODE', max_length=50)  
    name = models.CharField(db_column='NAME', max_length=255)  
    date_b = models.DateTimeField(db_column='Date_B')  
    date_e = models.DateTimeField(db_column='Date_E')  

    class Meta:
        managed = False
        db_table = 'oms_kl_MedCareType'
